---
title: simconfig
sidebarTitle: simconfig
---

# `catalax.model.simconfig`

## Classes

### `SimulationConfig` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/simconfig.py#L9" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>


Configuration for simulation parameters

